Class: Google::Apis::DnsV1::DnsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DnsV1::DnsService
- Defined in:
- lib/google/apis/dns_v1/service.rb
Overview
Cloud DNS API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://dns.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Atomically updates the ResourceRecordSet collection.
-
#create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Creates a new ManagedZone.
-
#create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Creates a new policy.
-
#create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Creates a new ResourceRecordSet.
-
#create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Creates a new Response Policy.
-
#create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Creates a new Response Policy Rule.
-
#delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created ManagedZone.
-
#delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created policy.
-
#delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse
Deletes a previously created ResourceRecordSet.
-
#delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created Response Policy.
-
#delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created Response Policy Rule.
-
#get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Fetches the representation of an existing Change.
-
#get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKey
Fetches the representation of an existing DnsKey.
-
#get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Fetches the representation of an existing ManagedZone.
-
#get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Gets the access control policy for a resource.
-
#get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Fetches the representation of an existing Operation.
-
#get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Fetches the representation of an existing policy.
-
#get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Project
Fetches the representation of an existing Project.
-
#get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Fetches the representation of an existing ResourceRecordSet.
-
#get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Fetches the representation of an existing Response Policy.
-
#get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Fetches the representation of an existing Response Policy Rule.
-
#initialize ⇒ DnsService
constructor
A new instance of DnsService.
-
#list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListChangesResponse
Enumerates Changes to a ResourceRecordSet collection.
-
#list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKeysListResponse
Enumerates DnsKeys to a ResourceRecordSet collection.
-
#list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZoneOperationsListResponse
Enumerates Operations for the given ManagedZone.
-
#list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListManagedZonesResponse
Enumerates ManagedZones that have been created but not yet deleted.
-
#list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesListResponse
Enumerates all policies associated with a project.
-
#list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListResourceRecordSetsResponse
Enumerates ResourceRecordSets that you have created but not yet deleted.
-
#list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesListResponse
Enumerates all Response Policies associated with a project.
-
#list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesListResponse
Enumerates all Response Policy Rules associated with a project.
-
#patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Applies a partial update to an existing ManagedZone.
-
#patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesPatchResponse
Applies a partial update to an existing policy.
-
#patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Applies a partial update to an existing ResourceRecordSet.
-
#patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesPatchResponse
Applies a partial update to an existing Response Policy.
-
#patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse
Applies a partial update to an existing Response Policy Rule.
-
#set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Sets the access control policy on the specified resource.
-
#test_managed_zone_iam_permissions(resource, google_iam_v1_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Updates an existing ManagedZone.
-
#update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesUpdateResponse
Updates an existing policy.
-
#update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesUpdateResponse
Updates an existing Response Policy.
-
#update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
Updates an existing Response Policy Rule.
Constructor Details
#initialize ⇒ DnsService
Returns a new instance of DnsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/dns_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-dns_v1', client_version: Google::Apis::DnsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/dns_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/dns_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Atomically updates the ResourceRecordSet collection. Note: While dns.changes.
create is the baseline permission required to invoke this method, additional
permissions are checked depending on the specific additions or deletions
contained in the payload.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/apis/dns_v1/service.rb', line 84 def create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes', ) command.request_representation = Google::Apis::DnsV1::Change::Representation command.request_object = change_object command.response_representation = Google::Apis::DnsV1::Change::Representation command.response_class = Google::Apis::DnsV1::Change command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Creates a new ManagedZone. Note: While dns.managedZones.create is the
baseline permission required to invoke this method, additional permissions are
required if the managed zone configuration references other resources.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/dns_v1/service.rb', line 391 def create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::ManagedZone::Representation command.response_class = Google::Apis::DnsV1::ManagedZone command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Creates a new policy.
737 738 739 740 741 742 743 744 745 746 747 748 |
# File 'lib/google/apis/dns_v1/service.rb', line 737 def create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/policies', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::Policy::Representation command.response_class = Google::Apis::DnsV1::Policy command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Creates a new ResourceRecordSet.
1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 |
# File 'lib/google/apis/dns_v1/service.rb', line 1002 def create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets', ) command.request_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.request_object = resource_record_set_object command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Creates a new Response Policy
1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 |
# File 'lib/google/apis/dns_v1/service.rb', line 1236 def create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/responsePolicies', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicy command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Creates a new Response Policy Rule.
1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 |
# File 'lib/google/apis/dns_v1/service.rb', line 1466 def create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRule command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created ManagedZone.
430 431 432 433 434 435 436 437 438 |
# File 'lib/google/apis/dns_v1/service.rb', line 430 def delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created policy. Fails if the policy is still being referenced by a network.
776 777 778 779 780 781 782 783 784 |
# File 'lib/google/apis/dns_v1/service.rb', line 776 def delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/policies/{policy}', ) command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse
Deletes a previously created ResourceRecordSet.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/google/apis/dns_v1/service.rb', line 1046 def delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.response_representation = Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created Response Policy. Fails if the response policy is non-empty or still being referenced by a network.
1275 1276 1277 1278 1279 1280 1281 1282 1283 |
# File 'lib/google/apis/dns_v1/service.rb', line 1275 def delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created Response Policy Rule.
1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 |
# File 'lib/google/apis/dns_v1/service.rb', line 1507 def delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Fetches the representation of an existing Change.
127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/dns_v1/service.rb', line 127 def get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes/{changeId}', ) command.response_representation = Google::Apis::DnsV1::Change::Representation command.response_class = Google::Apis::DnsV1::Change command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['changeId'] = change_id unless change_id.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKey
Fetches the representation of an existing DnsKey.
220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/dns_v1/service.rb', line 220 def get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/dnsKeys/{dnsKeyId}', ) command.response_representation = Google::Apis::DnsV1::DnsKey::Representation command.response_class = Google::Apis::DnsV1::DnsKey command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['dnsKeyId'] = dns_key_id unless dns_key_id.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['digestType'] = digest_type unless digest_type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Fetches the representation of an existing ManagedZone.
466 467 468 469 470 471 472 473 474 475 476 |
# File 'lib/google/apis/dns_v1/service.rb', line 466 def get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.response_representation = Google::Apis::DnsV1::ManagedZone::Representation command.response_class = Google::Apis::DnsV1::ManagedZone command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/dns_v1/service.rb', line 502 def get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1GetIamPolicyRequest::Representation command.request_object = google_iam_v1_get_iam_policy_request_object command.response_representation = Google::Apis::DnsV1::GoogleIamV1Policy::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Fetches the representation of an existing Operation.
308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/google/apis/dns_v1/service.rb', line 308 def get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/operations/{operation}', ) command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['operation'] = operation unless operation.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Fetches the representation of an existing policy.
811 812 813 814 815 816 817 818 819 820 821 |
# File 'lib/google/apis/dns_v1/service.rb', line 811 def get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/policies/{policy}', ) command.response_representation = Google::Apis::DnsV1::Policy::Representation command.response_class = Google::Apis::DnsV1::Policy command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Project
Fetches the representation of an existing Project.
964 965 966 967 968 969 970 971 972 973 |
# File 'lib/google/apis/dns_v1/service.rb', line 964 def get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}', ) command.response_representation = Google::Apis::DnsV1::Project::Representation command.response_class = Google::Apis::DnsV1::Project command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Fetches the representation of an existing ResourceRecordSet.
1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 |
# File 'lib/google/apis/dns_v1/service.rb', line 1090 def get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Fetches the representation of an existing Response Policy.
1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 |
# File 'lib/google/apis/dns_v1/service.rb', line 1310 def get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicy command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Fetches the representation of an existing Response Policy Rule.
1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 |
# File 'lib/google/apis/dns_v1/service.rb', line 1545 def get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRule command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListChangesResponse
Enumerates Changes to a ResourceRecordSet collection.
173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/google/apis/dns_v1/service.rb', line 173 def list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes', ) command.response_representation = Google::Apis::DnsV1::ListChangesResponse::Representation command.response_class = Google::Apis::DnsV1::ListChangesResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortBy'] = sort_by unless sort_by.nil? command.query['sortOrder'] = sort_order unless sort_order.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKeysListResponse
Enumerates DnsKeys to a ResourceRecordSet collection.
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/google/apis/dns_v1/service.rb', line 267 def list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/dnsKeys', ) command.response_representation = Google::Apis::DnsV1::DnsKeysListResponse::Representation command.response_class = Google::Apis::DnsV1::DnsKeysListResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['digestType'] = digest_type unless digest_type.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZoneOperationsListResponse
Enumerates Operations for the given ManagedZone.
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/google/apis/dns_v1/service.rb', line 351 def list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/operations', ) command.response_representation = Google::Apis::DnsV1::ManagedZoneOperationsListResponse::Representation command.response_class = Google::Apis::DnsV1::ManagedZoneOperationsListResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortBy'] = sort_by unless sort_by.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListManagedZonesResponse
Enumerates ManagedZones that have been created but not yet deleted.
542 543 544 545 546 547 548 549 550 551 552 553 |
# File 'lib/google/apis/dns_v1/service.rb', line 542 def list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones', ) command.response_representation = Google::Apis::DnsV1::ListManagedZonesResponse::Representation command.response_class = Google::Apis::DnsV1::ListManagedZonesResponse command.params['project'] = project unless project.nil? command.query['dnsName'] = dns_name unless dns_name.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesListResponse
Enumerates all policies associated with a project.
849 850 851 852 853 854 855 856 857 858 859 |
# File 'lib/google/apis/dns_v1/service.rb', line 849 def list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/policies', ) command.response_representation = Google::Apis::DnsV1::PoliciesListResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesListResponse command.params['project'] = project unless project.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListResourceRecordSetsResponse
Enumerates ResourceRecordSets that you have created but not yet deleted.
1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 |
# File 'lib/google/apis/dns_v1/service.rb', line 1149 def list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets', ) command.response_representation = Google::Apis::DnsV1::ListResourceRecordSetsResponse::Representation command.response_class = Google::Apis::DnsV1::ListResourceRecordSetsResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['filter'] = filter unless filter.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['name'] = name unless name.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['type'] = type unless type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesListResponse
Enumerates all Response Policies associated with a project.
1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 |
# File 'lib/google/apis/dns_v1/service.rb', line 1348 def list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies', ) command.response_representation = Google::Apis::DnsV1::ResponsePoliciesListResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesListResponse command.params['project'] = project unless project.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesListResponse
Enumerates all Response Policy Rules associated with a project.
1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 1597 |
# File 'lib/google/apis/dns_v1/service.rb', line 1586 def list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesListResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesListResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Applies a partial update to an existing ManagedZone.
582 583 584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/google/apis/dns_v1/service.rb', line 582 def patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesPatchResponse
Applies a partial update to an existing policy.
887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'lib/google/apis/dns_v1/service.rb', line 887 def patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/policies/{policy}', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::PoliciesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesPatchResponse command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Applies a partial update to an existing ResourceRecordSet.
1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 |
# File 'lib/google/apis/dns_v1/service.rb', line 1196 def patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.request_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.request_object = resource_record_set_object command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesPatchResponse
Applies a partial update to an existing Response Policy.
1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 |
# File 'lib/google/apis/dns_v1/service.rb', line 1386 def patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePoliciesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesPatchResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse
Applies a partial update to an existing Response Policy Rule.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 |
# File 'lib/google/apis/dns_v1/service.rb', line 1627 def patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/google/apis/dns_v1/service.rb', line 621 def set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1SetIamPolicyRequest::Representation command.request_object = google_iam_v1_set_iam_policy_request_object command.response_representation = Google::Apis::DnsV1::GoogleIamV1Policy::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_managed_zone_iam_permissions(resource, google_iam_v1_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this returns an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
660 661 662 663 664 665 666 667 668 669 670 |
# File 'lib/google/apis/dns_v1/service.rb', line 660 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Updates an existing ManagedZone.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/google/apis/dns_v1/service.rb', line 699 def update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesUpdateResponse
Updates an existing policy.
927 928 929 930 931 932 933 934 935 936 937 938 939 |
# File 'lib/google/apis/dns_v1/service.rb', line 927 def update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/policies/{policy}', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::PoliciesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesUpdateResponse command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesUpdateResponse
Updates an existing Response Policy.
1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 |
# File 'lib/google/apis/dns_v1/service.rb', line 1426 def update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePoliciesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesUpdateResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
Updates an existing Response Policy Rule.
1670 1671 1672 1673 1674 1675 1676 1677 1678 1679 1680 1681 1682 1683 |
# File 'lib/google/apis/dns_v1/service.rb', line 1670 def update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |