Class: Google::Apis::DnsV1::ManagedZoneOperationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedZoneOperationsListResponse

Returns a new instance of ManagedZoneOperationsListResponse.



1091
1092
1093
# File 'lib/google/apis/dns_v1/classes.rb', line 1091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


1072
1073
1074
# File 'lib/google/apis/dns_v1/classes.rb', line 1072

def kind
  @kind
end

#next_page_tokenString

This field indicates that more results are available beyond the last page displayed. To fetch the results, make another list request and use this value as your page token. This lets you retrieve the complete contents of a very large collection one page at a time. However, if the contents of the collection change between the first and last paginated list request, the set of all elements returned are an inconsistent view of the collection. You can't retrieve a consistent snapshot of a collection larger than the maximum page size. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1084
1085
1086
# File 'lib/google/apis/dns_v1/classes.rb', line 1084

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::DnsV1::Operation>

The operation resources. Corresponds to the JSON property operations

Returns:



1089
1090
1091
# File 'lib/google/apis/dns_v1/classes.rb', line 1089

def operations
  @operations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1096
1097
1098
1099
1100
# File 'lib/google/apis/dns_v1/classes.rb', line 1096

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
end