Class: Google::Apis::DnsV1::ManagedZonePeeringConfigTargetNetwork
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::ManagedZonePeeringConfigTargetNetwork
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Instance Attribute Summary collapse
-
#deactivate_time ⇒ String
The time at which the zone was deactivated, in RFC 3339 date-time format.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#network_url ⇒ String
The fully qualified URL of the VPC network to forward queries to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedZonePeeringConfigTargetNetwork
constructor
A new instance of ManagedZonePeeringConfigTargetNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedZonePeeringConfigTargetNetwork
Returns a new instance of ManagedZonePeeringConfigTargetNetwork.
1152 1153 1154 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deactivate_time ⇒ String
The time at which the zone was deactivated, in RFC 3339 date-time format. An
empty string indicates that the peering connection is active. The producer
network can deactivate a zone. The zone is automatically deactivated if the
producer network that the zone targeted is deleted. Output only.
Corresponds to the JSON property deactivateTime
1138 1139 1140 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1138 def deactivate_time @deactivate_time end |
#kind ⇒ String
Corresponds to the JSON property kind
1143 1144 1145 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1143 def kind @kind end |
#network_url ⇒ String
The fully qualified URL of the VPC network to forward queries to. This should
be formatted like https://www.googleapis.com/compute/v1/projects/project/
global/networks/network`
Corresponds to the JSON propertynetworkUrl`
1150 1151 1152 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1150 def network_url @network_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1157 1158 1159 1160 1161 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1157 def update!(**args) @deactivate_time = args[:deactivate_time] if args.key?(:deactivate_time) @kind = args[:kind] if args.key?(:kind) @network_url = args[:network_url] if args.key?(:network_url) end |