Class: Google::Apis::DnsV1::ResourceRecordSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb

Overview

A unit of data that is returned by the DNS servers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceRecordSet

Returns a new instance of ResourceRecordSet.



2470
2471
2472
# File 'lib/google/apis/dns_v1/classes.rb', line 2470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/dns_v1/classes.rb', line 2434

def kind
  @kind
end

#nameString

For example, www.example.com. Corresponds to the JSON property name

Returns:

  • (String)


2439
2440
2441
# File 'lib/google/apis/dns_v1/classes.rb', line 2439

def name
  @name
end

#routing_policyGoogle::Apis::DnsV1::RrSetRoutingPolicy

A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection. Corresponds to the JSON property routingPolicy



2446
2447
2448
# File 'lib/google/apis/dns_v1/classes.rb', line 2446

def routing_policy
  @routing_policy
end

#rrdatasArray<String>

As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples. Corresponds to the JSON property rrdatas

Returns:

  • (Array<String>)


2452
2453
2454
# File 'lib/google/apis/dns_v1/classes.rb', line 2452

def rrdatas
  @rrdatas
end

#signature_rrdatasArray<String>

As defined in RFC 4034 (section 3.2). Corresponds to the JSON property signatureRrdatas

Returns:

  • (Array<String>)


2457
2458
2459
# File 'lib/google/apis/dns_v1/classes.rb', line 2457

def signature_rrdatas
  @signature_rrdatas
end

#ttlFixnum

Number of seconds that this ResourceRecordSet can be cached by resolvers. Corresponds to the JSON property ttl

Returns:

  • (Fixnum)


2462
2463
2464
# File 'lib/google/apis/dns_v1/classes.rb', line 2462

def ttl
  @ttl
end

#typeString

The identifier of a supported record type. See the list of Supported DNS record types. Corresponds to the JSON property type

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/dns_v1/classes.rb', line 2468

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2475
2476
2477
2478
2479
2480
2481
2482
2483
# File 'lib/google/apis/dns_v1/classes.rb', line 2475

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @routing_policy = args[:routing_policy] if args.key?(:routing_policy)
  @rrdatas = args[:rrdatas] if args.key?(:rrdatas)
  @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas)
  @ttl = args[:ttl] if args.key?(:ttl)
  @type = args[:type] if args.key?(:type)
end