Class: Google::Apis::DnsV1::ResponsePolicyRulesListResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResponsePolicyRulesListResponse

Returns a new instance of ResponsePolicyRulesListResponse.



2751
2752
2753
# File 'lib/google/apis/dns_v1/classes.rb', line 2751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

This field indicates that more results are available beyond the last page displayed. To fetch the results, make another list request and use this value as your page token. This lets you retrieve the complete contents of a very large collection one page at a time. However, if the contents of the collection change between the first and last paginated list request, the set of all elements returned are an inconsistent view of the collection. You can't retrieve a consistent snapshot of a collection larger than the maximum page size. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2744
2745
2746
# File 'lib/google/apis/dns_v1/classes.rb', line 2744

def next_page_token
  @next_page_token
end

#response_policy_rulesArray<Google::Apis::DnsV1::ResponsePolicyRule>

The Response Policy Rule resources. Corresponds to the JSON property responsePolicyRules



2749
2750
2751
# File 'lib/google/apis/dns_v1/classes.rb', line 2749

def response_policy_rules
  @response_policy_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2756
2757
2758
2759
# File 'lib/google/apis/dns_v1/classes.rb', line 2756

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @response_policy_rules = args[:response_policy_rules] if args.key?(:response_policy_rules)
end