Class: Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicyGeoPolicyItem
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicyGeoPolicyItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Overview
ResourceRecordSet data for one geo location.
Instance Attribute Summary collapse
-
#health_checked_targets ⇒ Google::Apis::DnsV1::RrSetRoutingPolicyHealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#location ⇒ String
The geo-location granularity is a GCP region.
-
#rrdatas ⇒ Array<String>
Corresponds to the JSON property
rrdatas. -
#signature_rrdatas ⇒ Array<String>
DNSSEC generated signatures for all the
rrdatawithin this item.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicyGeoPolicyItem
constructor
A new instance of RrSetRoutingPolicyGeoPolicyGeoPolicyItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicyGeoPolicyItem
Returns a new instance of RrSetRoutingPolicyGeoPolicyGeoPolicyItem.
2133 2134 2135 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2133 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_checked_targets ⇒ Google::Apis::DnsV1::RrSetRoutingPolicyHealthCheckTargets
HealthCheckTargets describes endpoints to health-check when responding to
Routing Policy queries. Only the healthy endpoints will be included in the
response. Set either internal_load_balancer or external_endpoints. Do not
set both.
Corresponds to the JSON property healthCheckedTargets
2107 2108 2109 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2107 def health_checked_targets @health_checked_targets end |
#kind ⇒ String
Corresponds to the JSON property kind
2112 2113 2114 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2112 def kind @kind end |
#location ⇒ String
The geo-location granularity is a GCP region. This location string should
correspond to a GCP region. e.g. "us-east1", "southamerica-east1", "asia-east1"
, etc.
Corresponds to the JSON property location
2119 2120 2121 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2119 def location @location end |
#rrdatas ⇒ Array<String>
Corresponds to the JSON property rrdatas
2124 2125 2126 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2124 def rrdatas @rrdatas end |
#signature_rrdatas ⇒ Array<String>
DNSSEC generated signatures for all the rrdata within this item. When using
health-checked targets for DNSSEC-enabled zones, you can only use at most one
health-checked IP address per item.
Corresponds to the JSON property signatureRrdatas
2131 2132 2133 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2131 def signature_rrdatas @signature_rrdatas end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2138 2139 2140 2141 2142 2143 2144 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2138 def update!(**args) @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets) @kind = args[:kind] if args.key?(:kind) @location = args[:location] if args.key?(:location) @rrdatas = args[:rrdatas] if args.key?(:rrdatas) @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas) end |