Class: Google::Apis::DnsV1::RrSetRoutingPolicyLoadBalancerTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb

Overview

The configuration for an individual load balancer to health check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicyLoadBalancerTarget

Returns a new instance of RrSetRoutingPolicyLoadBalancerTarget.



2290
2291
2292
# File 'lib/google/apis/dns_v1/classes.rb', line 2290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The frontend IP address of the load balancer to health check. Corresponds to the JSON property ipAddress

Returns:

  • (String)


2246
2247
2248
# File 'lib/google/apis/dns_v1/classes.rb', line 2246

def ip_address
  @ip_address
end

#ip_protocolString

The protocol of the load balancer to health check. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


2251
2252
2253
# File 'lib/google/apis/dns_v1/classes.rb', line 2251

def ip_protocol
  @ip_protocol
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2256
2257
2258
# File 'lib/google/apis/dns_v1/classes.rb', line 2256

def kind
  @kind
end

#load_balancer_typeString

The type of load balancer specified by this target. This value must match the configuration of the load balancer located at the LoadBalancerTarget's IP address, port, and region. Use the following: - regionalL4ilb: for a regional internal passthrough Network Load Balancer. - regionalL7ilb: for a regional internal Application Load Balancer. - globalL7ilb: for a global internal Application Load Balancer. Corresponds to the JSON property loadBalancerType

Returns:

  • (String)


2266
2267
2268
# File 'lib/google/apis/dns_v1/classes.rb', line 2266

def load_balancer_type
  @load_balancer_type
end

#network_urlString

The fully qualified URL of the network that the load balancer is attached to. This should be formatted like https://www.googleapis.com/compute/v1/projects/ project/global/networks/network`. Corresponds to the JSON propertynetworkUrl`

Returns:

  • (String)


2273
2274
2275
# File 'lib/google/apis/dns_v1/classes.rb', line 2273

def network_url
  @network_url
end

#portString

The configured port of the load balancer. Corresponds to the JSON property port

Returns:

  • (String)


2278
2279
2280
# File 'lib/google/apis/dns_v1/classes.rb', line 2278

def port
  @port
end

#projectString

The project ID in which the load balancer is located. Corresponds to the JSON property project

Returns:

  • (String)


2283
2284
2285
# File 'lib/google/apis/dns_v1/classes.rb', line 2283

def project
  @project
end

#regionString

The region in which the load balancer is located. Corresponds to the JSON property region

Returns:

  • (String)


2288
2289
2290
# File 'lib/google/apis/dns_v1/classes.rb', line 2288

def region
  @region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2295
2296
2297
2298
2299
2300
2301
2302
2303
2304
# File 'lib/google/apis/dns_v1/classes.rb', line 2295

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type)
  @network_url = args[:network_url] if args.key?(:network_url)
  @port = args[:port] if args.key?(:port)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
end