Class: Google::Apis::DnsV1::DnsService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DnsV1::DnsService
- Defined in:
- lib/google/apis/dns_v1/service.rb
Overview
Cloud DNS API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://dns.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Atomically updates the ResourceRecordSet collection.
-
#create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Creates a new ManagedZone.
-
#create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Creates a new policy.
-
#create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Creates a new ResourceRecordSet.
-
#create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Creates a new Response Policy.
-
#create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Creates a new Response Policy Rule.
-
#delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created ManagedZone.
-
#delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created policy.
-
#delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse
Deletes a previously created ResourceRecordSet.
-
#delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created Response Policy.
-
#delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
Deletes a previously created Response Policy Rule.
-
#get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Fetches the representation of an existing Change.
-
#get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKey
Fetches the representation of an existing DnsKey.
-
#get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Fetches the representation of an existing ManagedZone.
-
#get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Gets the access control policy for a resource.
-
#get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Fetches the representation of an existing Operation.
-
#get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Fetches the representation of an existing policy.
-
#get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Project
Fetches the representation of an existing Project.
-
#get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Fetches the representation of an existing ResourceRecordSet.
-
#get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Fetches the representation of an existing Response Policy.
-
#get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Fetches the representation of an existing Response Policy Rule.
-
#initialize ⇒ DnsService
constructor
A new instance of DnsService.
-
#list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListChangesResponse
Enumerates Changes to a ResourceRecordSet collection.
-
#list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKeysListResponse
Enumerates DnsKeys to a ResourceRecordSet collection.
-
#list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZoneOperationsListResponse
Enumerates Operations for the given ManagedZone.
-
#list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListManagedZonesResponse
Enumerates ManagedZones that have been created but not yet deleted.
-
#list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesListResponse
Enumerates all policies associated with a project.
-
#list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListResourceRecordSetsResponse
Enumerates ResourceRecordSets that you have created but not yet deleted.
-
#list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesListResponse
Enumerates all Response Policies associated with a project.
-
#list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesListResponse
Enumerates all Response Policy Rules associated with a project.
-
#patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Applies a partial update to an existing ManagedZone.
-
#patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesPatchResponse
Applies a partial update to an existing policy.
-
#patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Applies a partial update to an existing ResourceRecordSet.
-
#patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesPatchResponse
Applies a partial update to an existing Response Policy.
-
#patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse
Applies a partial update to an existing Response Policy Rule.
-
#set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Sets the access control policy on the specified resource.
-
#test_managed_zone_iam_permissions(resource, google_iam_v1_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Updates an existing ManagedZone.
-
#update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesUpdateResponse
Updates an existing policy.
-
#update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesUpdateResponse
Updates an existing Response Policy.
-
#update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
Updates an existing Response Policy Rule.
Constructor Details
#initialize ⇒ DnsService
Returns a new instance of DnsService.
47 48 49 50 51 52 |
# File 'lib/google/apis/dns_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-dns_v1', client_version: Google::Apis::DnsV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/dns_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/dns_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Atomically updates the ResourceRecordSet collection.
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/google/apis/dns_v1/service.rb', line 81 def create_change(project, managed_zone, change_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes', ) command.request_representation = Google::Apis::DnsV1::Change::Representation command.request_object = change_object command.response_representation = Google::Apis::DnsV1::Change::Representation command.response_class = Google::Apis::DnsV1::Change command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Creates a new ManagedZone.
386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/google/apis/dns_v1/service.rb', line 386 def create_managed_zone(project, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::ManagedZone::Representation command.response_class = Google::Apis::DnsV1::ManagedZone command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Creates a new policy.
732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/dns_v1/service.rb', line 732 def create_policy(project, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/policies', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::Policy::Representation command.response_class = Google::Apis::DnsV1::Policy command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Creates a new ResourceRecordSet.
997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 |
# File 'lib/google/apis/dns_v1/service.rb', line 997 def create_resource_record_set(project, managed_zone, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets', ) command.request_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.request_object = resource_record_set_object command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Creates a new Response Policy
1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 |
# File 'lib/google/apis/dns_v1/service.rb', line 1231 def create_response_policy(project, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/responsePolicies', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicy command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Creates a new Response Policy Rule.
1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 |
# File 'lib/google/apis/dns_v1/service.rb', line 1461 def create_response_policy_rule(project, response_policy, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRule command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created ManagedZone.
425 426 427 428 429 430 431 432 433 |
# File 'lib/google/apis/dns_v1/service.rb', line 425 def delete_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created policy. Fails if the policy is still being referenced by a network.
771 772 773 774 775 776 777 778 779 |
# File 'lib/google/apis/dns_v1/service.rb', line 771 def delete_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/policies/{policy}', ) command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse
Deletes a previously created ResourceRecordSet.
1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 |
# File 'lib/google/apis/dns_v1/service.rb', line 1041 def delete_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.response_representation = Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSetsDeleteResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created Response Policy. Fails if the response policy is non-empty or still being referenced by a network.
1270 1271 1272 1273 1274 1275 1276 1277 1278 |
# File 'lib/google/apis/dns_v1/service.rb', line 1270 def delete_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... }
This method returns an undefined value.
Deletes a previously created Response Policy Rule.
1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 |
# File 'lib/google/apis/dns_v1/service.rb', line 1502 def delete_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Change
Fetches the representation of an existing Change.
124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/google/apis/dns_v1/service.rb', line 124 def get_change(project, managed_zone, change_id, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes/{changeId}', ) command.response_representation = Google::Apis::DnsV1::Change::Representation command.response_class = Google::Apis::DnsV1::Change command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['changeId'] = change_id unless change_id.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKey
Fetches the representation of an existing DnsKey.
217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/google/apis/dns_v1/service.rb', line 217 def get_dns_key(project, managed_zone, dns_key_id, client_operation_id: nil, digest_type: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/dnsKeys/{dnsKeyId}', ) command.response_representation = Google::Apis::DnsV1::DnsKey::Representation command.response_class = Google::Apis::DnsV1::DnsKey command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['dnsKeyId'] = dns_key_id unless dns_key_id.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['digestType'] = digest_type unless digest_type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZone
Fetches the representation of an existing ManagedZone.
461 462 463 464 465 466 467 468 469 470 471 |
# File 'lib/google/apis/dns_v1/service.rb', line 461 def get_managed_zone(project, managed_zone, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.response_representation = Google::Apis::DnsV1::ManagedZone::Representation command.response_class = Google::Apis::DnsV1::ManagedZone command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/google/apis/dns_v1/service.rb', line 497 def get_managed_zone_iam_policy(resource, google_iam_v1_get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1GetIamPolicyRequest::Representation command.request_object = google_iam_v1_get_iam_policy_request_object command.response_representation = Google::Apis::DnsV1::GoogleIamV1Policy::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Fetches the representation of an existing Operation.
305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/google/apis/dns_v1/service.rb', line 305 def get_managed_zone_operation(project, managed_zone, operation, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/operations/{operation}', ) command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['operation'] = operation unless operation.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Policy
Fetches the representation of an existing policy.
806 807 808 809 810 811 812 813 814 815 816 |
# File 'lib/google/apis/dns_v1/service.rb', line 806 def get_policy(project, policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/policies/{policy}', ) command.response_representation = Google::Apis::DnsV1::Policy::Representation command.response_class = Google::Apis::DnsV1::Policy command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Project
Fetches the representation of an existing Project.
959 960 961 962 963 964 965 966 967 968 |
# File 'lib/google/apis/dns_v1/service.rb', line 959 def get_project(project, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}', ) command.response_representation = Google::Apis::DnsV1::Project::Representation command.response_class = Google::Apis::DnsV1::Project command.params['project'] = project unless project.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Fetches the representation of an existing ResourceRecordSet.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 |
# File 'lib/google/apis/dns_v1/service.rb', line 1085 def get_resource_record_set(project, managed_zone, name, type, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicy
Fetches the representation of an existing Response Policy.
1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 |
# File 'lib/google/apis/dns_v1/service.rb', line 1305 def get_response_policy(project, response_policy, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicy command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRule
Fetches the representation of an existing Response Policy Rule.
1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 |
# File 'lib/google/apis/dns_v1/service.rb', line 1540 def get_response_policy_rule(project, response_policy, response_policy_rule, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRule command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListChangesResponse
Enumerates Changes to a ResourceRecordSet collection.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/google/apis/dns_v1/service.rb', line 170 def list_changes(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/changes', ) command.response_representation = Google::Apis::DnsV1::ListChangesResponse::Representation command.response_class = Google::Apis::DnsV1::ListChangesResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortBy'] = sort_by unless sort_by.nil? command.query['sortOrder'] = sort_order unless sort_order.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::DnsKeysListResponse
Enumerates DnsKeys to a ResourceRecordSet collection.
264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/google/apis/dns_v1/service.rb', line 264 def list_dns_keys(project, managed_zone, digest_type: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/dnsKeys', ) command.response_representation = Google::Apis::DnsV1::DnsKeysListResponse::Representation command.response_class = Google::Apis::DnsV1::DnsKeysListResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['digestType'] = digest_type unless digest_type.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ManagedZoneOperationsListResponse
Enumerates Operations for the given ManagedZone.
348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/google/apis/dns_v1/service.rb', line 348 def list_managed_zone_operations(project, managed_zone, max_results: nil, page_token: nil, sort_by: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/operations', ) command.response_representation = Google::Apis::DnsV1::ManagedZoneOperationsListResponse::Representation command.response_class = Google::Apis::DnsV1::ManagedZoneOperationsListResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortBy'] = sort_by unless sort_by.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListManagedZonesResponse
Enumerates ManagedZones that have been created but not yet deleted.
537 538 539 540 541 542 543 544 545 546 547 548 |
# File 'lib/google/apis/dns_v1/service.rb', line 537 def list_managed_zones(project, dns_name: nil, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones', ) command.response_representation = Google::Apis::DnsV1::ListManagedZonesResponse::Representation command.response_class = Google::Apis::DnsV1::ListManagedZonesResponse command.params['project'] = project unless project.nil? command.query['dnsName'] = dns_name unless dns_name.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesListResponse
Enumerates all policies associated with a project.
844 845 846 847 848 849 850 851 852 853 854 |
# File 'lib/google/apis/dns_v1/service.rb', line 844 def list_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/policies', ) command.response_representation = Google::Apis::DnsV1::PoliciesListResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesListResponse command.params['project'] = project unless project.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ListResourceRecordSetsResponse
Enumerates ResourceRecordSets that you have created but not yet deleted.
1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 1154 1155 1156 1157 1158 |
# File 'lib/google/apis/dns_v1/service.rb', line 1144 def list_resource_record_sets(project, managed_zone, filter: nil, max_results: nil, name: nil, page_token: nil, type: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets', ) command.response_representation = Google::Apis::DnsV1::ListResourceRecordSetsResponse::Representation command.response_class = Google::Apis::DnsV1::ListResourceRecordSetsResponse command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['filter'] = filter unless filter.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['name'] = name unless name.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['type'] = type unless type.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesListResponse
Enumerates all Response Policies associated with a project.
1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 |
# File 'lib/google/apis/dns_v1/service.rb', line 1343 def list_response_policies(project, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies', ) command.response_representation = Google::Apis::DnsV1::ResponsePoliciesListResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesListResponse command.params['project'] = project unless project.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesListResponse
Enumerates all Response Policy Rules associated with a project.
1581 1582 1583 1584 1585 1586 1587 1588 1589 1590 1591 1592 |
# File 'lib/google/apis/dns_v1/service.rb', line 1581 def list_response_policy_rules(project, response_policy, max_results: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules', ) command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesListResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesListResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['maxResults'] = max_results unless max_results.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Applies a partial update to an existing ManagedZone.
577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/google/apis/dns_v1/service.rb', line 577 def patch_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesPatchResponse
Applies a partial update to an existing policy.
882 883 884 885 886 887 888 889 890 891 892 893 894 |
# File 'lib/google/apis/dns_v1/service.rb', line 882 def patch_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/policies/{policy}', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::PoliciesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesPatchResponse command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResourceRecordSet
Applies a partial update to an existing ResourceRecordSet.
1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 |
# File 'lib/google/apis/dns_v1/service.rb', line 1191 def patch_resource_record_set(project, managed_zone, name, type, resource_record_set_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/managedZones/{managedZone}/rrsets/{name}/{type}', ) command.request_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.request_object = resource_record_set_object command.response_representation = Google::Apis::DnsV1::ResourceRecordSet::Representation command.response_class = Google::Apis::DnsV1::ResourceRecordSet command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.params['name'] = name unless name.nil? command.params['type'] = type unless type.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesPatchResponse
Applies a partial update to an existing Response Policy.
1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 |
# File 'lib/google/apis/dns_v1/service.rb', line 1381 def patch_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePoliciesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesPatchResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse
Applies a partial update to an existing Response Policy Rule.
1622 1623 1624 1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 |
# File 'lib/google/apis/dns_v1/service.rb', line 1622 def patch_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesPatchResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/google/apis/dns_v1/service.rb', line 616 def set_managed_zone_iam_policy(resource, google_iam_v1_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1SetIamPolicyRequest::Representation command.request_object = google_iam_v1_set_iam_policy_request_object command.response_representation = Google::Apis::DnsV1::GoogleIamV1Policy::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_managed_zone_iam_permissions(resource, google_iam_v1_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this returns an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/google/apis/dns_v1/service.rb', line 655 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'dns/v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse::Representation command.response_class = Google::Apis::DnsV1::GoogleIamV1TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::Operation
Updates an existing ManagedZone.
694 695 696 697 698 699 700 701 702 703 704 705 706 |
# File 'lib/google/apis/dns_v1/service.rb', line 694 def update_managed_zone(project, managed_zone, managed_zone_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/managedZones/{managedZone}', ) command.request_representation = Google::Apis::DnsV1::ManagedZone::Representation command.request_object = managed_zone_object command.response_representation = Google::Apis::DnsV1::Operation::Representation command.response_class = Google::Apis::DnsV1::Operation command.params['project'] = project unless project.nil? command.params['managedZone'] = managed_zone unless managed_zone.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::PoliciesUpdateResponse
Updates an existing policy.
922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'lib/google/apis/dns_v1/service.rb', line 922 def update_policy(project, policy, policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/policies/{policy}', ) command.request_representation = Google::Apis::DnsV1::Policy::Representation command.request_object = policy_object command.response_representation = Google::Apis::DnsV1::PoliciesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::PoliciesUpdateResponse command.params['project'] = project unless project.nil? command.params['policy'] = policy unless policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePoliciesUpdateResponse
Updates an existing Response Policy.
1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 |
# File 'lib/google/apis/dns_v1/service.rb', line 1421 def update_response_policy(project, response_policy, response_policy_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicy::Representation command.request_object = response_policy_object command.response_representation = Google::Apis::DnsV1::ResponsePoliciesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePoliciesUpdateResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
Updates an existing Response Policy Rule.
1665 1666 1667 1668 1669 1670 1671 1672 1673 1674 1675 1676 1677 1678 |
# File 'lib/google/apis/dns_v1/service.rb', line 1665 def update_response_policy_rule(project, response_policy, response_policy_rule, response_policy_rule_object = nil, client_operation_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:put, 'dns/v1/projects/{project}/responsePolicies/{responsePolicy}/rules/{responsePolicyRule}', ) command.request_representation = Google::Apis::DnsV1::ResponsePolicyRule::Representation command.request_object = response_policy_rule_object command.response_representation = Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse::Representation command.response_class = Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse command.params['project'] = project unless project.nil? command.params['responsePolicy'] = response_policy unless response_policy.nil? command.params['responsePolicyRule'] = response_policy_rule unless response_policy_rule.nil? command.query['clientOperationId'] = client_operation_id unless client_operation_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |