Class: Google::Apis::DnsV1::ListResourceRecordSetsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::ListResourceRecordSetsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#rrsets ⇒ Array<Google::Apis::DnsV1::ResourceRecordSet>
The resource record set resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListResourceRecordSetsResponse
constructor
A new instance of ListResourceRecordSetsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListResourceRecordSetsResponse
Returns a new instance of ListResourceRecordSetsResponse.
2463 2464 2465 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
2444 2445 2446 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2444 def kind @kind end |
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
2456 2457 2458 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2456 def next_page_token @next_page_token end |
#rrsets ⇒ Array<Google::Apis::DnsV1::ResourceRecordSet>
The resource record set resources.
Corresponds to the JSON property rrsets
2461 2462 2463 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2461 def rrsets @rrsets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2468 2469 2470 2471 2472 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2468 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rrsets = args[:rrsets] if args.key?(:rrsets) end |