Class: Google::Apis::DnsV1::PoliciesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::PoliciesListResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
Type of resource.
-
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page displayed.
-
#policies ⇒ Array<Google::Apis::DnsV1::Policy>
The policy resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PoliciesListResponse
constructor
A new instance of PoliciesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PoliciesListResponse
Returns a new instance of PoliciesListResponse.
1518 1519 1520 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Type of resource.
Corresponds to the JSON property kind
1499 1500 1501 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1499 def kind @kind end |
#next_page_token ⇒ String
This field indicates that more results are available beyond the last page
displayed. To fetch the results, make another list request and use this value
as your page token. This lets you retrieve the complete contents of a very
large collection one page at a time. However, if the contents of the
collection change between the first and last paginated list request, the set
of all elements returned are an inconsistent view of the collection. You can't
retrieve a consistent snapshot of a collection larger than the maximum page
size.
Corresponds to the JSON property nextPageToken
1511 1512 1513 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1511 def next_page_token @next_page_token end |
#policies ⇒ Array<Google::Apis::DnsV1::Policy>
The policy resources.
Corresponds to the JSON property policies
1516 1517 1518 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1516 def policies @policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1523 1524 1525 1526 1527 |
# File 'lib/google/apis/dns_v1/classes.rb', line 1523 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @policies = args[:policies] if args.key?(:policies) end |