Class: Google::Apis::DnsV1::ResourceRecordSet
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::ResourceRecordSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Overview
A unit of data that is returned by the DNS servers.
Instance Attribute Summary collapse
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#name ⇒ String
For example, www.example.com.
-
#routing_policy ⇒ Google::Apis::DnsV1::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned dynamically with the response varying based on configured properties such as geolocation or by weighted random selection.
-
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples.
-
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
-
#ttl ⇒ Fixnum
Number of seconds that this
ResourceRecordSetcan be cached by resolvers. -
#type ⇒ String
The identifier of a supported record type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceRecordSet
constructor
A new instance of ResourceRecordSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceRecordSet
Returns a new instance of ResourceRecordSet.
2408 2409 2410 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Corresponds to the JSON property kind
2372 2373 2374 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2372 def kind @kind end |
#name ⇒ String
For example, www.example.com.
Corresponds to the JSON property name
2377 2378 2379 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2377 def name @name end |
#routing_policy ⇒ Google::Apis::DnsV1::RrSetRoutingPolicy
A RRSetRoutingPolicy represents ResourceRecordSet data that is returned
dynamically with the response varying based on configured properties such as
geolocation or by weighted random selection.
Corresponds to the JSON property routingPolicy
2384 2385 2386 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2384 def routing_policy @routing_policy end |
#rrdatas ⇒ Array<String>
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see
examples.
Corresponds to the JSON property rrdatas
2390 2391 2392 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2390 def rrdatas @rrdatas end |
#signature_rrdatas ⇒ Array<String>
As defined in RFC 4034 (section 3.2).
Corresponds to the JSON property signatureRrdatas
2395 2396 2397 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2395 def signature_rrdatas @signature_rrdatas end |
#ttl ⇒ Fixnum
Number of seconds that this ResourceRecordSet can be cached by resolvers.
Corresponds to the JSON property ttl
2400 2401 2402 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2400 def ttl @ttl end |
#type ⇒ String
The identifier of a supported record type. See the list of Supported DNS
record types.
Corresponds to the JSON property type
2406 2407 2408 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2406 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2413 2414 2415 2416 2417 2418 2419 2420 2421 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2413 def update!(**args) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @routing_policy = args[:routing_policy] if args.key?(:routing_policy) @rrdatas = args[:rrdatas] if args.key?(:rrdatas) @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas) @ttl = args[:ttl] if args.key?(:ttl) @type = args[:type] if args.key?(:type) end |