Class: Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::ResponsePolicyRulesUpdateResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Instance Attribute Summary collapse
-
#response_policy_rule ⇒ Google::Apis::DnsV1::ResponsePolicyRule
A Response Policy Rule is a selector that applies its behavior to queries that match the selector.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResponsePolicyRulesUpdateResponse
constructor
A new instance of ResponsePolicyRulesUpdateResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResponsePolicyRulesUpdateResponse
Returns a new instance of ResponsePolicyRulesUpdateResponse.
2798 2799 2800 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2798 def initialize(**args) update!(**args) end |
Instance Attribute Details
#response_policy_rule ⇒ Google::Apis::DnsV1::ResponsePolicyRule
A Response Policy Rule is a selector that applies its behavior to queries that
match the selector. Selectors are DNS names, which may be wildcards or exact
matches. Each DNS query subject to a Response Policy matches at most one
ResponsePolicyRule, as identified by the dns_name field with the longest
matching suffix.
Corresponds to the JSON property responsePolicyRule
2796 2797 2798 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2796 def response_policy_rule @response_policy_rule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2803 2804 2805 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2803 def update!(**args) @response_policy_rule = args[:response_policy_rule] if args.key?(:response_policy_rule) end |