Class: Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Overview
Configures a RRSetRoutingPolicy that routes based on the geo location of the
querying user.
Instance Attribute Summary collapse
-
#enable_fencing ⇒ Boolean
(also: #enable_fencing?)
Without fencing, if health check fails for all configured items in the current geo bucket, we failover to the next nearest geo bucket.
-
#items ⇒ Array<Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicyGeoPolicyItem>
The primary geo routing configuration.
-
#kind ⇒ String
Corresponds to the JSON property
kind.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicy
constructor
A new instance of RrSetRoutingPolicyGeoPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicyGeoPolicy
Returns a new instance of RrSetRoutingPolicyGeoPolicy.
2085 2086 2087 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_fencing ⇒ Boolean Also known as: enable_fencing?
Without fencing, if health check fails for all configured items in the current
geo bucket, we failover to the next nearest geo bucket. With fencing, if
health checking is enabled, as long as some targets in the current geo bucket
are healthy, we return only the healthy targets. However, if all targets are
unhealthy, we don't failover to the next nearest bucket; instead, we return
all the items in the current bucket even when all targets are unhealthy.
Corresponds to the JSON property enableFencing
2071 2072 2073 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2071 def enable_fencing @enable_fencing end |
#items ⇒ Array<Google::Apis::DnsV1::RrSetRoutingPolicyGeoPolicyGeoPolicyItem>
The primary geo routing configuration. If there are multiple items with the
same location, an error is returned instead.
Corresponds to the JSON property items
2078 2079 2080 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2078 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
2083 2084 2085 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2083 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2090 2091 2092 2093 2094 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2090 def update!(**args) @enable_fencing = args[:enable_fencing] if args.key?(:enable_fencing) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |