Class: Google::Apis::DnsV1::RrSetRoutingPolicyLoadBalancerTarget
- Inherits:
-
Object
- Object
- Google::Apis::DnsV1::RrSetRoutingPolicyLoadBalancerTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb
Overview
The configuration for an individual load balancer to health check.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The frontend IP address of the load balancer to health check.
-
#ip_protocol ⇒ String
The protocol of the load balancer to health check.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#load_balancer_type ⇒ String
The type of load balancer specified by this target.
-
#network_url ⇒ String
The fully qualified URL of the network that the load balancer is attached to.
-
#port ⇒ String
The configured port of the load balancer.
-
#project ⇒ String
The project ID in which the load balancer is located.
-
#region ⇒ String
The region in which the load balancer is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RrSetRoutingPolicyLoadBalancerTarget
constructor
A new instance of RrSetRoutingPolicyLoadBalancerTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RrSetRoutingPolicyLoadBalancerTarget
Returns a new instance of RrSetRoutingPolicyLoadBalancerTarget.
2228 2229 2230 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The frontend IP address of the load balancer to health check.
Corresponds to the JSON property ipAddress
2184 2185 2186 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2184 def ip_address @ip_address end |
#ip_protocol ⇒ String
The protocol of the load balancer to health check.
Corresponds to the JSON property ipProtocol
2189 2190 2191 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2189 def ip_protocol @ip_protocol end |
#kind ⇒ String
Corresponds to the JSON property kind
2194 2195 2196 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2194 def kind @kind end |
#load_balancer_type ⇒ String
The type of load balancer specified by this target. This value must match the
configuration of the load balancer located at the LoadBalancerTarget's IP
address, port, and region. Use the following: - regionalL4ilb: for a
regional internal passthrough Network Load Balancer. - regionalL7ilb: for a
regional internal Application Load Balancer. - globalL7ilb: for a global
internal Application Load Balancer.
Corresponds to the JSON property loadBalancerType
2204 2205 2206 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2204 def load_balancer_type @load_balancer_type end |
#network_url ⇒ String
The fully qualified URL of the network that the load balancer is attached to.
This should be formatted like https://www.googleapis.com/compute/v1/projects/
project/global/networks/network`.
Corresponds to the JSON propertynetworkUrl`
2211 2212 2213 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2211 def network_url @network_url end |
#port ⇒ String
The configured port of the load balancer.
Corresponds to the JSON property port
2216 2217 2218 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2216 def port @port end |
#project ⇒ String
The project ID in which the load balancer is located.
Corresponds to the JSON property project
2221 2222 2223 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2221 def project @project end |
#region ⇒ String
The region in which the load balancer is located.
Corresponds to the JSON property region
2226 2227 2228 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2226 def region @region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2233 2234 2235 2236 2237 2238 2239 2240 2241 2242 |
# File 'lib/google/apis/dns_v1/classes.rb', line 2233 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @kind = args[:kind] if args.key?(:kind) @load_balancer_type = args[:load_balancer_type] if args.key?(:load_balancer_type) @network_url = args[:network_url] if args.key?(:network_url) @port = args[:port] if args.key?(:port) @project = args[:project] if args.key?(:project) @region = args[:region] if args.key?(:region) end |