Class: Google::Apis::DnsV1::RrSetRoutingPolicyWrrPolicyWrrPolicyItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dns_v1/classes.rb,
lib/google/apis/dns_v1/representations.rb,
lib/google/apis/dns_v1/representations.rb

Overview

A routing block which contains the routing information for one WRR item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RrSetRoutingPolicyWrrPolicyWrrPolicyItem

Returns a new instance of RrSetRoutingPolicyWrrPolicyWrrPolicyItem.



2351
2352
2353
# File 'lib/google/apis/dns_v1/classes.rb', line 2351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#health_checked_targetsGoogle::Apis::DnsV1::RrSetRoutingPolicyHealthCheckTargets

HealthCheckTargets describes endpoints to health-check when responding to Routing Policy queries. Only the healthy endpoints will be included in the response. Set either internal_load_balancer or external_endpoints. Do not set both. Corresponds to the JSON property healthCheckedTargets



2324
2325
2326
# File 'lib/google/apis/dns_v1/classes.rb', line 2324

def health_checked_targets
  @health_checked_targets
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


2329
2330
2331
# File 'lib/google/apis/dns_v1/classes.rb', line 2329

def kind
  @kind
end

#rrdatasArray<String>

Corresponds to the JSON property rrdatas

Returns:

  • (Array<String>)


2334
2335
2336
# File 'lib/google/apis/dns_v1/classes.rb', line 2334

def rrdatas
  @rrdatas
end

#signature_rrdatasArray<String>

DNSSEC generated signatures for all the rrdata within this item. When using health-checked targets for DNSSEC-enabled zones, you can only use at most one health-checked IP address per item. Corresponds to the JSON property signatureRrdatas

Returns:

  • (Array<String>)


2341
2342
2343
# File 'lib/google/apis/dns_v1/classes.rb', line 2341

def signature_rrdatas
  @signature_rrdatas
end

#weightFloat

The weight corresponding to this WrrPolicyItem object. When multiple WrrPolicyItem objects are configured, the probability of returning an WrrPolicyItem object's data is proportional to its weight relative to the sum of weights configured for all items. This weight must be non-negative. Corresponds to the JSON property weight

Returns:

  • (Float)


2349
2350
2351
# File 'lib/google/apis/dns_v1/classes.rb', line 2349

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2356
2357
2358
2359
2360
2361
2362
# File 'lib/google/apis/dns_v1/classes.rb', line 2356

def update!(**args)
  @health_checked_targets = args[:health_checked_targets] if args.key?(:health_checked_targets)
  @kind = args[:kind] if args.key?(:kind)
  @rrdatas = args[:rrdatas] if args.key?(:rrdatas)
  @signature_rrdatas = args[:signature_rrdatas] if args.key?(:signature_rrdatas)
  @weight = args[:weight] if args.key?(:weight)
end